package dtgateway

import (
	"GtDataStore/app/cmd/dtgateway/internal/svc"
	"GtDataStore/app/cmd/dtgateway/internal/types"
	"GtDataStore/app/cmd/organization/pb"
	"GtDataStore/common/xerr"
	"context"

	"github.com/zeromicro/go-zero/core/logx"
)

type WorkingChestLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewWorkingChestLogic(ctx context.Context, svcCtx *svc.ServiceContext) *WorkingChestLogic {
	return &WorkingChestLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *WorkingChestLogic) WorkingChest(req *types.DcWorkingReq) (resp *types.CommonResponse, err error) {
	list, err := l.svcCtx.OrganizationRpc.GetWorkingChestByCode(l.ctx, &pb.DcWorkingReq{
		ProjectId:  req.ProjectId,
		DeviceCode: req.DeviceCode,
		Stime:      req.Stime,
		Etime:      req.Etime,
		Page:       req.Page,
		PageSize:   req.PageSize,
		Order:      req.Order,
	})
	if err != nil {
		return nil, err
	}

	return &types.CommonResponse{
		Code: xerr.OK,
		Msg:  xerr.MapErrMsg(xerr.OK),
		Data: list,
	}, nil
}
